pub struct ClassicScriptDescriptor {
pub source: ClassicScriptSource,
pub execution: ClassicScriptExecution,
}Expand description
A classic script source together with its requested scheduling mode.
Fields
source: ClassicScriptSourceexecution: ClassicScriptExecutionTrait Implementations
Sourceimpl Clone for ClassicScriptDescriptor
impl Clone for ClassicScriptDescriptor
Sourcefn clone(&self) -> ClassicScriptDescriptor
fn clone(&self) -> ClassicScriptDescriptor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClassicScriptDescriptor
impl Debug for ClassicScriptDescriptor
impl Eq for ClassicScriptDescriptor
Sourceimpl PartialEq for ClassicScriptDescriptor
impl PartialEq for ClassicScriptDescriptor
Sourcefn eq(&self, other: &ClassicScriptDescriptor) -> bool
fn eq(&self, other: &ClassicScriptDescriptor) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ClassicScriptDescriptor